pub struct MockWebAuthnApi {
WebAuthnApi_expectations: MockWebAuthnApi_WebAuthnApi,
}Fields
WebAuthnApi_expectations: MockWebAuthnApi_WebAuthnApiImplementations
Sourceimpl MockWebAuthnApi
impl MockWebAuthnApi
Sourcepub fn checkpoint(&mut self)
pub fn checkpoint(&mut self)
Validate that all current expectations for all methods have been satisfied, and discard them.
Sourcepub fn new() -> Self
pub fn new() -> Self
Create a new mock object with no expectations.
This method will not be generated if the real struct
already has a new method. However, it will be
generated if the struct implements a trait with a new
method. The trait’s new method can still be called
like <MockX as TraitY>::new
Sourceimpl MockWebAuthnApi
impl MockWebAuthnApi
Sourcepub fn expect_assertion_options(&mut self) -> &mut Expectation
pub fn expect_assertion_options(&mut self) -> &mut Expectation
Create an Expectation for mocking the assertion_options method
Sourcepub fn expect_attestation_options(&mut self) -> &mut Expectation
pub fn expect_attestation_options(&mut self) -> &mut Expectation
Create an Expectation for mocking the attestation_options method
Sourcepub fn expect_delete(&mut self) -> &mut Expectation
pub fn expect_delete(&mut self) -> &mut Expectation
Create an Expectation for mocking the delete method
Sourcepub fn expect_get(&mut self) -> &mut Expectation
pub fn expect_get(&mut self) -> &mut Expectation
Create an Expectation for mocking the get method
Sourcepub fn expect_post(&mut self) -> &mut Expectation
pub fn expect_post(&mut self) -> &mut Expectation
Create an Expectation for mocking the post method
Sourcepub fn expect_update_credential(&mut self) -> &mut Expectation
pub fn expect_update_credential(&mut self) -> &mut Expectation
Create an Expectation for mocking the update_credential method